@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBTree.cpp,v 1.27 2007/04/24 05:00:47 vkurland Exp $
+  $Id: FWBTree.cpp 551 2008-09-25 07:14:38Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,13 +17,13 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 
 #include <qobject.h>
@@ -37,7 +37,9 @@
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Host.h"
 #include "fwbuilder/Network.h"
+#include "fwbuilder/NetworkIPv6.h"
 #include "fwbuilder/IPv4.h"
+#include "fwbuilder/IPv6.h"
 #include "fwbuilder/DNSName.h"
 #include "fwbuilder/AddressTable.h"
 #include "fwbuilder/AddressRange.h"
@@ -46,8 +48,10 @@
 #include "fwbuilder/CustomService.h"
 #include "fwbuilder/IPService.h"
 #include "fwbuilder/ICMPService.h"
+#include "fwbuilder/ICMP6Service.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
+#include "fwbuilder/UserService.h"
 #include "fwbuilder/ServiceGroup.h"
 #include "fwbuilder/Interval.h"
 #include "fwbuilder/IntervalGroup.h"
@@ -59,8 +63,6 @@
 using namespace std;
 using namespace libfwbuilder;
 
-FWBTree *FWBTree::standardObjectTreeFormat=NULL;
-
 const char* systemObjects[] = {
     "Objects",
     "Objects/Addresses",
@@ -79,7 +81,7 @@ const char* systemObjects[] = {
     "Services/TCP",
     "Services/UDP",
     "Services/TagServices",
-
+    "Services/Users",
     "Firewalls",
 
     "Time",
@@ -91,26 +93,28 @@ map<string,bool> standardIDs;
 
 FWBTree::FWBTree()
 {
-    assert(standardObjectTreeFormat==NULL);
-    standardObjectTreeFormat=this;
-
     systemGroupPaths[Library::TYPENAME]       = "";
 
     systemGroupPaths[IPv4::TYPENAME]          = "Objects/Addresses";
+    systemGroupPaths[IPv6::TYPENAME]          = "Objects/Addresses";
     systemGroupPaths[DNSName::TYPENAME]       = "Objects/DNS Names";
     systemGroupPaths[AddressTable::TYPENAME]  = "Objects/Address Tables";
     systemGroupPaths[AddressRange::TYPENAME]  = "Objects/Address Ranges";
     systemGroupPaths[ObjectGroup::TYPENAME]   = "Objects/Groups";
     systemGroupPaths[Host::TYPENAME]          = "Objects/Hosts";
     systemGroupPaths[Network::TYPENAME]       = "Objects/Networks";
+    systemGroupPaths[NetworkIPv6::TYPENAME]   = "Objects/Networks";
 
     systemGroupPaths[ServiceGroup::TYPENAME]  = "Services/Groups";
     systemGroupPaths[CustomService::TYPENAME] = "Services/Custom";
     systemGroupPaths[IPService::TYPENAME]     = "Services/IP";
     systemGroupPaths[ICMPService::TYPENAME]   = "Services/ICMP";
+    systemGroupPaths[ICMP6Service::TYPENAME]  = "Services/ICMP";
     systemGroupPaths[TCPService::TYPENAME]    = "Services/TCP";
     systemGroupPaths[UDPService::TYPENAME]    = "Services/UDP";
-    systemGroupPaths[TagService::TYPENAME]          = "Services/TagServices";
+    systemGroupPaths[UserService::TYPENAME]   = "Services/Users";
+
+    systemGroupPaths[TagService::TYPENAME]    = "Services/TagServices";
 
     systemGroupPaths[Firewall::TYPENAME]      = "Firewalls";
 
@@ -127,9 +131,15 @@ FWBTree::FWBTree()
     systemGroupTypes[Network::TYPENAME]=       ObjectGroup::TYPENAME;
     systemGroupNames[Network::TYPENAME]=       "Networks"       ;
 
+    systemGroupTypes[NetworkIPv6::TYPENAME]=   ObjectGroup::TYPENAME;
+    systemGroupNames[NetworkIPv6::TYPENAME]=   "Networks"       ;
+
     systemGroupTypes[IPv4::TYPENAME]=          ObjectGroup::TYPENAME;
     systemGroupNames[IPv4::TYPENAME]=          "Addresses"      ;
 
+    systemGroupTypes[IPv6::TYPENAME]=          ObjectGroup::TYPENAME;
+    systemGroupNames[IPv6::TYPENAME]=          "Addresses"      ;
+
     systemGroupTypes[DNSName::TYPENAME]=       ObjectGroup::TYPENAME;
     systemGroupNames[DNSName::TYPENAME]=       "DNS Names"      ;
 
@@ -151,14 +161,20 @@ FWBTree::FWBTree()
     systemGroupTypes[ICMPService::TYPENAME]=   ServiceGroup::TYPENAME;
     systemGroupNames[ICMPService::TYPENAME]=   "ICMP"          ;
 
+    systemGroupTypes[ICMP6Service::TYPENAME]=  ServiceGroup::TYPENAME;
+    systemGroupNames[ICMP6Service::TYPENAME]=  "ICMP"          ;
+
     systemGroupTypes[TCPService::TYPENAME]=    ServiceGroup::TYPENAME;
     systemGroupNames[TCPService::TYPENAME]=    "TCP"           ;
 
     systemGroupTypes[UDPService::TYPENAME]=    ServiceGroup::TYPENAME;
     systemGroupNames[UDPService::TYPENAME]=    "UDP"           ;
 
-    systemGroupTypes[TagService::TYPENAME]=          ServiceGroup::TYPENAME;
-    systemGroupNames[TagService::TYPENAME]=          "TagService"           ;
+    systemGroupTypes[TagService::TYPENAME]=    ServiceGroup::TYPENAME;
+    systemGroupNames[TagService::TYPENAME]=    "TagService"    ;
+
+    systemGroupTypes[UserService::TYPENAME]=   ServiceGroup::TYPENAME;
+    systemGroupNames[UserService::TYPENAME]=   "Users"    ;
 
     systemGroupTypes[ServiceGroup::TYPENAME]=  ServiceGroup::TYPENAME;
     systemGroupNames[ServiceGroup::TYPENAME]=  "Groups"        ;
@@ -218,7 +234,7 @@ FWBTree::FWBTree()
     standardIDs["stdid18_1"]=true;
     standardIDs["stdid19"]  =true;
     standardIDs["stdid19_1"]=true;
-    
+
 
     copyMenuState[""] = false;
     copyMenuState["Firewalls"] = false;
@@ -257,6 +273,7 @@ FWBTree::FWBTree()
     cutMenuState["Services/IP"] = false;
     cutMenuState["Services/TCP"] = false;
     cutMenuState["Services/UDP"] = false;
+    cutMenuState["Services/Users"] = false;
     cutMenuState["Services/TagServices"] = false;
     cutMenuState["Time"] = false;
 
@@ -277,6 +294,7 @@ FWBTree::FWBTree()
     pasteMenuState["Services/IP"] = true;
     pasteMenuState["Services/TCP"] = true;
     pasteMenuState["Services/UDP"] = true;
+    pasteMenuState["Services/Users"] = true;
     pasteMenuState["Services/TagServices"] = true;
     pasteMenuState["Time"] = true;
 
@@ -297,9 +315,9 @@ FWBTree::FWBTree()
     deleteMenuState["Services/IP"] = false;
     deleteMenuState["Services/TCP"] = false;
     deleteMenuState["Services/UDP"] = false;
+    deleteMenuState["Services/Users"] = false;
     deleteMenuState["Services/TagServices"] = false;
     deleteMenuState["Time"] = false;
-
 }
 
 /**
@@ -313,7 +331,8 @@ FWBTree::FWBTree()
 bool FWBTree::isSystem(FWObject *obj)
 {
     if (Library::isA(obj))
-        return (obj->getId()==STANDARD_LIB || obj->getId()==DELETED_LIB);
+        return (obj->getId()==FWObjectDatabase::STANDARD_LIB_ID ||
+                obj->getId()==FWObjectDatabase::DELETED_OBJECTS_ID);
 
     if (FWObjectDatabase::isA(obj)) return true;
 
@@ -328,10 +347,10 @@ bool FWBTree::isSystem(FWObject *obj)
 
 bool FWBTree::isStandardId(FWObject *obj)
 {
-    return standardIDs[ obj->getId() ];
+    return standardIDs[ FWObjectDatabase::getStringId(obj->getId()).c_str() ];
 }
 
-bool FWBTree::validateForInsertion(FWObject *target,FWObject *obj)
+bool FWBTree::validateForInsertion(FWObject *target, FWObject *obj)
 {
     if (fwbdebug) qDebug("FWBTree::validateForInsertion  target %s  obj %s",
                          target->getTypeName().c_str(),
@@ -340,18 +359,19 @@ bool FWBTree::validateForInsertion(FWObject *target,FWObject *obj)
     if (Host::isA(target)      && Interface::isA(obj))   return true;
     if (Firewall::isA(target)  && Interface::isA(obj))   return true;
     if (Interface::isA(target) && IPv4::isA(obj))        return true;
+    if (Interface::isA(target) && IPv6::isA(obj))        return true;
     if (Interface::isA(target) && physAddress::isA(obj)) return true;
 
-    QString parentType = standardObjectTreeFormat->systemGroupTypes[obj->getTypeName().c_str()];
-    QString parentName = standardObjectTreeFormat->systemGroupNames[obj->getTypeName().c_str()];
+    QString parentType = systemGroupTypes[obj->getTypeName().c_str()];
+    QString parentName = systemGroupNames[obj->getTypeName().c_str()];
 
 /* parentType or/and parentName are going to be empty if information
  * about object obj is missing in systemGroupTypes/Names tables
  */
     if (parentType.isEmpty() || parentName.isEmpty()) return false;
 
-    if (target->getTypeName() == string(parentType.latin1()) &&
-	target->getName()     == string(parentName.latin1()) )
+    if (target->getTypeName() == string(parentType.toLatin1()) &&
+	target->getName()     == string(parentName.toLatin1()) )
         return true;
 
     return false;
@@ -361,8 +381,8 @@ void FWBTree::getStandardSlotForObject(const QString &objType,
                                        QString &parentType,
                                        QString &parentName)
 {
-    parentType = standardObjectTreeFormat->systemGroupTypes[objType];
-    parentName = standardObjectTreeFormat->systemGroupNames[objType];
+    parentType = systemGroupTypes[objType];
+    parentName = systemGroupNames[objType];
 }
 
 /**
@@ -372,7 +392,7 @@ void FWBTree::getStandardSlotForObject(const QString &objType,
  */
 FWObject* FWBTree::getStandardSlotForObject(FWObject* lib,const QString &objType)
 {
-    QString path = standardObjectTreeFormat->systemGroupPaths[objType];
+    QString path = systemGroupPaths[objType];
 
     if (path.isEmpty()) return lib;
 
@@ -380,13 +400,13 @@ FWObject* FWBTree::getStandardSlotForObject(FWObject* lib,const QString &objType
     QString level2 = path.section('/',1,1);
 
     FWObject::iterator i=std::find_if(lib->begin(),lib->end(),
-                                      FWObjectNameEQPredicate(level1.ascii()));
+        FWObjectNameEQPredicate(static_cast<const char*>(level1.toAscii())));
     if (i==lib->end()) return NULL;
     FWObject *l1obj = *i;
     if (level2.isEmpty()) return l1obj;
 
     i=std::find_if(l1obj->begin(),l1obj->end(),
-                   FWObjectNameEQPredicate(level2.ascii()));
+        FWObjectNameEQPredicate(static_cast<const char*>(level2.toAscii())));
     if (i==l1obj->end()) return NULL;
     return (*i);
 }
@@ -396,7 +416,7 @@ FWObject* FWBTree::createNewLibrary(FWObjectDatabase *db)
 
     FWObject *nlib = db->create(Library::TYPENAME);
     db->add(nlib);
-    nlib->setName( string(QObject::tr("New Library").utf8()) );
+    nlib->setName( string(QObject::tr("New Library").toUtf8()) );
 
     FWObject *o1 = db->create(ObjectGroup::TYPENAME);
     o1->setName("Objects");
@@ -409,11 +429,11 @@ FWObject* FWBTree::createNewLibrary(FWObjectDatabase *db)
     o2 = db->create(ObjectGroup::TYPENAME);
     o2->setName("DNS Names");
     o1->add(o2);
-    
+
     o2 = db->create(ObjectGroup::TYPENAME);
     o2->setName("Address Tables");
     o1->add(o2);
-    
+
     o2 = db->create(ObjectGroup::TYPENAME);
     o2->setName("Groups");
     o1->add(o2);
@@ -454,6 +474,10 @@ FWObject* FWBTree::createNewLibrary(FWObjectDatabase *db)
     o2->setName("UDP");
     o1->add(o2);
 
+    o2 = db->create(ServiceGroup::TYPENAME);
+    o2->setName("Users");
+    o1->add(o2);
+
     o2 = db->create(ServiceGroup::TYPENAME);
     o2->setName("Custom");
     o1->add(o2);
