@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FWObjectDropArea.h,v 1.2 2006/10/22 04:39:36 vkurland Exp $
+  $Id: FWObjectDropArea.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,41 +27,57 @@
 #ifndef __FWOBJECTDROPAREA_H_
 #define __FWOBJECTDROPAREA_H_
 
-#include "config.h"
-#include <fwobjectdroparea_q.h>
+#include "../../config.h"
+#include <ui_fwobjectdroparea_q.h>
 
 #include "fwbuilder/FWObject.h"
+#include <QPaintEvent>
+#include <QMenu>
+#include <QContextMenuEvent>
+#include <QDropEvent>
+#include <QDragEnterEvent>
+#include <QPixmap>
 
 class QWidget;
 class QPixmap;
-class QPopupMenu;
+class QMenu;
 class QContextMenuEvent;
 class QDropEvent;
 class QDragEnterEvent;
 
-class FWObjectDropArea : public FWObjectDropArea_q
+class FWObjectDropArea : public QWidget//Ui::FWObjectDropArea_q
 {
     Q_OBJECT
- private:
-        libfwbuilder::FWObject *object;
- protected:
-        void paintEvent(QPaintEvent *ev);
-        void contextMenuEvent (QContextMenuEvent * e);
-        void dropEvent( QDropEvent *ev);
-        void dragEnterEvent( QDragEnterEvent *ev);
-        
- public:
-    FWObjectDropArea(QWidget*p, const char * n = 0, WFlags f = 0);
-    libfwbuilder::FWObject * getObject(){return object;};
-    
-    bool isEmpty() {return object==NULL;};
 
-public slots:
+private:
+    libfwbuilder::FWObject *object;
+    QVector <QString> acceptedTypes ;
+    QString helperText ;
+
+protected:
+    void paintEvent(QPaintEvent *ev);
+    void contextMenuEvent (QContextMenuEvent * e);
+    void dropEvent( QDropEvent *ev);
+    void dragEnterEvent( QDragEnterEvent *ev);
+        
+public:
+    Ui::FWObjectDropArea_q *m_objectDropArea;
+    FWObjectDropArea(QWidget*p, const char * n = 0, Qt::WFlags f = 0);
+    ~FWObjectDropArea(); 
+    libfwbuilder::FWObject * getObject(){return object;};
+    void setObject(libfwbuilder::FWObject * o){ object = o ;};
+    void addAcceptedTypes (QString type){acceptedTypes.push_back(type);};
+    bool isEmpty() {return object==NULL;};
+    void setHelperText (QString text){helperText=text;}
+    virtual void mouseDoubleClickEvent ( QMouseEvent * event );
+    public slots:
     void insertObject(libfwbuilder::FWObject *o);
     void deleteObject();
     void pasteObject();
+    void showInTreeObject();
+    void editObject();
     
- signals:
+signals:
     void objectDeleted();
     void objectInserted();
     
