@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp 778 2009-03-07 04:32:28Z vadim $
+  $Id: FWWindow.cpp 973 2009-05-29 16:15:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -23,10 +23,12 @@
 
 */
 
-
 #include "../../config.h"
 #include "global.h"
 #include "check_update_url.h"
+#include "../../VERSION.h"
+#include "../../build_num"
+
 #include "utils.h"
 #include "utils_no_qt.h"
 
@@ -169,6 +171,8 @@ FWWindow::FWWindow() : QMainWindow(),   // QMainWindow(NULL, Qt::Desktop),
     m_mainWindow = new Ui::FWBMainWindow_q();
     m_mainWindow->setupUi(dynamic_cast<QMainWindow*>(this));
 
+    psd = NULL;
+
     prepareFileOpenRecentMenu();
 
     m_space = new QMdiArea(this);
@@ -373,7 +377,8 @@ void FWWindow::startupLoad()
     if (st->getCheckUpdates())
     {
         // start http query to get latest version from the web site
-        current_version_http_getter->get(QUrl(CHECK_UPDATE_URL));
+        QString url = QString(CHECK_UPDATE_URL).arg(VERSION).arg(st->getAppGUID());
+        current_version_http_getter->get(QUrl(url));
     }
 
     if (activeProject())
@@ -388,13 +393,15 @@ void FWWindow::startupLoad()
     {
         loadFile(file, auto_load_from_rcs_head_revision);
         updateOpenRecentMenu(file);
-     }
+    }
 
     if (! st->getBool("UI/NoStartTip"))
     {
         StartTipDialog *stdlg = new StartTipDialog();
-        stdlg->show();
-        stdlg->raise();
+        stdlg->run();
+
+        //stdlg->show();
+        //stdlg->raise();
     }
 }
 
@@ -1333,6 +1340,12 @@ void FWWindow::loadDataFromFw(Firewall *fw)
         activeProject()->loadDataFromFw(fw);
 }
 
+void FWWindow::insertObjectInTree(FWObject *parent, FWObject *obj)
+{
+    if (activeProject())
+        activeProject()->insertObjectInTree(parent, obj);
+}
+
 FWObject* FWWindow::createObject(const QString &objType,
                                                const QString &objName,
                                                FWObject *copyFrom)
