@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: InterfaceDialog.cpp 398 2008-07-21 01:47:01Z vadim $
+  $Id: InterfaceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -74,6 +74,11 @@ InterfaceDialog::~InterfaceDialog()
     delete m_dialog;
 }
 
+void InterfaceDialog::getHelpName(QString *str)
+{
+    *str = "InterfaceDialog";
+}
+
 void InterfaceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
