@@ -61,6 +61,11 @@ NATRuleOptionsDialog::NATRuleOptionsDialog(ProjectPanel *project, QWidget *paren
     init=false;
 }
 
+void NATRuleOptionsDialog::getHelpName(QString *str)
+{
+    *str = "NATRuleOptionsDialog";
+}
+
 void NATRuleOptionsDialog::loadFWObject(FWObject *o)
 {
     obj=o;
