@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.h,v 1.21 2006/07/19 06:21:08 vkurland Exp $
+  $Id: RCS.h 410 2008-07-25 04:42:30Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -55,10 +55,9 @@ class Revision {
     Revision(const Revision &r);
     Revision(const QString &file, const QString &rev="");
 
-    bool operator<(const Revision &r);
-    bool operator==(const Revision &r);
-    bool operator!=(const Revision &r);
-
+    bool operator<(const Revision &r) const;
+    bool operator==(const Revision &r) const;
+    bool operator!=(const Revision &r) const;
     void operator=(const Revision &r);
 };
 
@@ -111,7 +110,7 @@ class RCS : public QObject {
 
     QString               filename;
     bool                  temp;         // if filename is a temporary file
-    QValueList<Revision>  revisions;
+    QList<Revision>  revisions;
 
     /**
      * Retrieves RCS log.
@@ -127,10 +126,10 @@ class RCS : public QObject {
      * returns head revision of the file
      */
     QString getFileName()                  { return filename; }
-    void    setFileName(const QString &fn) { filename=fn;     }
+    void    setFileName(const QString &fn);
 
-    QValueList<Revision>::iterator begin() { return revisions.begin(); }
-    QValueList<Revision>::iterator end()   { return revisions.end();   }
+    QList<Revision>::iterator begin() { return revisions.begin(); }
+    QList<Revision>::iterator end()   { return revisions.end();   }
     
     void  add() throw(libfwbuilder::FWException);
 
@@ -219,7 +218,6 @@ class RCS : public QObject {
 
      virtual void readFromStdout();
      virtual void readFromStderr();
-     virtual void completeCI();
 };
 
 
