@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCSFilePreview.cpp 697 2008-12-20 07:37:17Z vadim $
+  $Id: RCSFilePreview.cpp 1049 2009-06-10 20:28:00Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,9 +28,11 @@
 
 #include "RCS.h"
 #include "RCSFilePreview.h"
+#include "FWBSettings.h"
 
 #include "fwbuilder/libfwbuilder-config.h"
 #include "fwbuilder/FWException.h"
+#include "fwbuilder/XMLTools.h"
 
 #include <QTreeWidget>
 #include <qregexp.h>
@@ -43,24 +45,18 @@
 using namespace std;
 using namespace libfwbuilder;
 
-int RCSViewItem::compare(QTreeWidgetItem *itm, int col, bool ) const
+bool RCSViewItem::operator<(const QTreeWidgetItem &other) const
 {
-    QString rev1 = text(col);
-    QString rev2 = itm->text(col);
+    int col = treeWidget()->sortColumn();
 
-    for(int i=1; ; i++)
-    {
-        QString v1 = rev1.section(".",i,i);
-        QString v2 = rev2.section(".",i,i);
-        if (v1=="" && v2=="") return 0;
-        if (v1==v2) continue;
-        if (v1=="" && v2!="") return -1;
-        if (v1!="" && v2=="") return 1;
-        if (v1.toInt()>v2.toInt()) return 1;
-        if (v1.toInt()<v2.toInt()) return -1;
-        i++;
-    }
-    return 0;
+    QString col_txt_1 = text(col);
+    QString col_txt_2 = other.text(col);
+
+    if (col==0)  // column 0 is revision number
+        return (XMLTools::version_compare(
+                    col_txt_1.toStdString(), col_txt_2.toStdString()) < 0);
+
+    return (col_txt_1 < col_txt_2);
 }
 
 RCSFilePreview::RCSFilePreview(QWidget *parent): QDialog(parent)
@@ -76,10 +72,15 @@ RCSFilePreview::RCSFilePreview(QWidget *parent): QDialog(parent)
              SIGNAL( itemActivated( QTreeWidgetItem*, int ) ),
              this, SLOT( accept() ) );
 
+    if (st->getRCSFilePreviewStyle()==1)
+        m_widget->list_view->setChecked(true);
+    else
+        m_widget->tree_view->setChecked(true);
+
     m_widget->RCSTreeView->setAllColumnsShowFocus( true );
-    m_widget->RCSTreeView->setSelectionMode(
-        QAbstractItemView::SingleSelection );
+    m_widget->RCSTreeView->setSelectionMode(QAbstractItemView::SingleSelection );
     m_widget->RCSTreeView->setRootIsDecorated( FALSE );
+
 //    m_widget->RCSTreeView->sortByColumn( 0, Qt::AscendingOrder );
 
     if (fwbdebug) qDebug("RCSFilePreview: constructor done");
@@ -92,6 +93,7 @@ RCSFilePreview::~RCSFilePreview()
 {
     if (fwbdebug) qDebug("~RCSFilePreview()  rcs=%p", rcs);
 //    if (rcs!=NULL) delete rcs;
+    st->setRCSFilePreviewSortColumn(m_widget->RCSTreeView->sortColumn());
 }
 
 void RCSFilePreview::openReadOnly()
@@ -124,6 +126,11 @@ bool RCSFilePreview::showFileRLog( const QString &filename )
     if (fwbdebug) qDebug("RCSFilePreview::showFileRLog filename=%s rcs=%p",
                          filename.toLocal8Bit().constData(),rcs);
 
+    current_file = filename;
+
+    m_widget->RCSTreeView->disconnect(
+        SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)));
+
     m_widget->RCSTreeView->clear();
 
     if (rcs!=NULL) delete rcs;
@@ -150,56 +157,120 @@ bool RCSFilePreview::showFileRLog( const QString &filename )
     QList<Revision>::iterator i;
     QList<RCSViewItem*> itemList;
     QList<RCSViewItem*>::iterator ili;
-    RCSViewItem* lastItem = NULL;
+    RCSViewItem* latest_revision_item = NULL;
+    RCSViewItem* latest_date_item = NULL;
+    string latest_revision = "1.0";
+    QString latest_date = "";
 
     for (i=rcs->revisions.begin(); i!=rcs->revisions.end(); ++i)
     {
-        rcsComments[(*i).rev]=(*i).log;
+        rcsComments[(*i).rev] = (*i).log;
 
-        if ((*i).rev.indexOf(QRegExp("^[0-9]+\\.[0-9]+$"))!=-1)
+        RCSViewItem *itm = NULL;
+        if (st->getRCSFilePreviewStyle()==1)
         {
-            RCSViewItem *itm = new RCSViewItem( rootItm );
-            itm->setText( 0, (*i).rev       );
-            itm->setText( 1, (*i).date      );
-            itm->setText( 2, (*i).author    );
-            itm->setText( 3, QString("    ")+(*i).locked_by );
-
+            // List style
+            itm = addRevision(*i, rootItm);
             itemList.push_back(itm);
-            lastItem = itm;
-        }
-
-        if ((*i).rev.indexOf(QRegExp("^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+"))!=-1)
+        } else
         {
-            QString branch_root = (*i).rev.section(".",0,1);
-            for (ili=itemList.begin(); ili!=itemList.end(); ++ili)
-                if ((*ili)->text(0) == branch_root)
+            // tree style
+            if ((*i).rev.indexOf(QRegExp("^[0-9]+\\.[0-9]+$"))!=-1)
+            {
+                itm = addRevision(*i, rootItm);
+                itemList.push_back(itm);
+            }
+
+            if ((*i).rev.indexOf(QRegExp("^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+"))!=-1)
+            {
+                QString branch_root = (*i).rev.section(".",0,1);
+                for (ili=itemList.begin(); ili!=itemList.end(); ++ili)
                 {
-                    QTreeWidgetItem   *br = *ili;
-                    if (br!=NULL)
+                    if ((*ili)->text(0) == branch_root)
                     {
-                        RCSViewItem *itm=new RCSViewItem(br);
-                        itm->setText( 0, (*i).rev       );
-                        itm->setText( 1, (*i).date      );
-                        itm->setText( 2, (*i).author    );
-                        itm->setText( 3, QString("    ")+(*i).locked_by );
+                        QTreeWidgetItem *br = *ili;
+                        if (br!=NULL)  itm = addRevision((*i), br);
                     }
                 }
+            }
+        }
+
+        string itm_revision = (*i).rev.toStdString();
+
+        if (XMLTools::version_compare(itm_revision, latest_revision) > 0)
+        {
+            latest_revision = itm_revision;
+            latest_revision_item = itm;
+        }
+
+        // This relies on the date string in the rcslog output
+        // being in sortable format. This is so for the "C" or "en_US"
+        // locale, but I am not sure about other locales.
+        if ((*i).date > latest_date)
+        {
+            latest_date = (*i).date;
+            latest_date_item = itm;
         }
     }
 
-    m_widget->RCSTreeView->scrollToItem( lastItem );
-
     m_widget->RCSTreeView->expandAll();
-//    m_widget->RCSTreeView->sortByColumn(0, Qt::AscendingOrder);
+
+    m_widget->RCSTreeView->sortByColumn(st->getRCSFilePreviewSortColumn(),
+                                        Qt::AscendingOrder);
+
+    // connect signal before setting current item so that
+    // selectedRevision gets control and updates rcs log panel
+    connect( m_widget->RCSTreeView,
+             SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
+             this, SLOT(selectedRevision(QTreeWidgetItem*)));
+
+    RCSViewItem* show_item = NULL;
+
+    if (m_widget->RCSTreeView->sortColumn()==0 && latest_revision_item)
+        show_item = latest_revision_item;
+
+    if (m_widget->RCSTreeView->sortColumn()==1 && latest_date_item)
+        show_item = latest_date_item;
+
+    if (show_item)
+    {
+        show_item->setSelected(true);
+        m_widget->RCSTreeView->expandItem(show_item->parent());
+        m_widget->RCSTreeView->setCurrentItem(show_item);
+        m_widget->RCSTreeView->scrollToItem(show_item);
+    }
+
+    // resize after parent of the current item was expanded
     m_widget->RCSTreeView->resizeColumnToContents ( 0 );
     m_widget->RCSTreeView->resizeColumnToContents ( 1 );
 
-    lastItem->setSelected( true );
-    m_widget->RCSTreeView->setCurrentItem( lastItem );
 
     return true;
 }
 
+RCSViewItem* RCSFilePreview::addRevision(Revision &rev,
+                                         QTreeWidgetItem *parent_item)
+{
+    RCSViewItem *itm = new RCSViewItem(parent_item);
+    itm->setText(0, rev.rev);
+    itm->setText(1, rev.date);
+    itm->setText(2, rev.author);
+    itm->setText(3, QString("    ") + rev.locked_by);
+    return itm;
+}
+
+void RCSFilePreview::switchToTreeView()
+{
+    st->setRCSFilePreviewStyle(0);  // 0 for backward compatibility
+    if (!current_file.isEmpty()) showFileRLog(current_file);
+}
+
+void RCSFilePreview::switchToListView()
+{
+    st->setRCSFilePreviewStyle(1);
+    if (!current_file.isEmpty()) showFileRLog(current_file);
+}
+
 RCS* RCSFilePreview::getSelectedRev()
 {
 
@@ -209,6 +280,10 @@ RCS* RCSFilePreview::getSelectedRev()
 
 }
 
-
-
-
+void RCSFilePreview::closeEvent(QCloseEvent *event)
+{
+    if (fwbdebug)
+        qDebug("RCSFilePreview::closeEvent");
+    st->setRCSFilePreviewSortColumn(m_widget->RCSTreeView->sortColumn());
+    QDialog::closeEvent(event);
+}
