@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: debugDialog.h,v 1.1 2004/05/23 20:32:06 vkurland Exp $
+  $Id: debugDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,16 +27,20 @@
 #ifndef __DEBUGDIALOG_H_
 #define __DEBUGDIALOG_H_
 
-#include "config.h"
-#include <debugdialog_q.h>
+#include "../../config.h"
+#include <ui_debugdialog_q.h>
+#include <QDialog>
 
 
-class debugDialog : public debugDialog_q
+class debugDialog : public QDialog
 {
     Q_OBJECT
+            
+    Ui::debugDialog_q *m_dialog;
 
  public:
     debugDialog(QWidget *parent);
+    ~debugDialog();
     
 };
 
