@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: filePropDialog.h,v 1.2 2005/05/28 21:16:18 vkurland Exp $
+  $Id: filePropDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,19 +29,23 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
+#include <QDialog>
 
-#include "config.h"
-#include <filepropdialog_q.h>
+#include "../../config.h"
+#include <ui_filepropdialog_q.h>
 
 class RCS;
 class QPrinter;
 
-class filePropDialog : public filePropDialog_q
+class filePropDialog : public QDialog
 {
     Q_OBJECT
+            
+    Ui::filePropDialog_q *m_dialog;
     
  public:
     filePropDialog(QWidget *parent, RCS *rcs);
+    ~filePropDialog();
     void setPrinter(QPrinter *printer);
     
  private: 
