@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newFirewallDialog.cpp 778 2009-03-07 04:32:28Z vadim $
+  $Id: newFirewallDialog.cpp 986 2009-05-31 21:22:59Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -238,8 +238,7 @@ void  newFirewallDialog::monitor()
 
         if ( idata->ostatus )
         {
-            idata->guessLabel(
-                readPlatform(m_dialog->platform).toLatin1().constData() );
+            idata->guessLabel(readPlatform(m_dialog->platform).toStdString());
 
             QString dn;
             if (idata->isDyn)        dn+="dyn";
@@ -341,11 +340,6 @@ bool newFirewallDialog::appropriate(const int page) const
 {
     int p  = page;
 
-    if (fwbdebug)
-    {
-        qDebug("newFirewallDialog::appropriate  p=%d",p);
-    }
-
     switch (p)
     {
     case 0:
@@ -500,7 +494,8 @@ void newFirewallDialog::fillInterfaceSLList()
 
         try
         {
-            idata.guessSecurityLevel( readPlatform(m_dialog->platform).toLatin1().constData() );
+            idata.guessSecurityLevel(
+                readPlatform(m_dialog->platform).toStdString() );
         }
         catch (FWException &ex)
         {
@@ -691,16 +686,18 @@ void newFirewallDialog::addInterface()
 void newFirewallDialog::selectedInterface(QTreeWidgetItem*cur,QTreeWidgetItem*)
 {
     QTreeWidgetItem *itm = cur; //current item
-
-    m_dialog->iface_name->setText( itm->text(0) );
-    m_dialog->iface_label->setText( itm->text(1) );
-    m_dialog->iface_addr->setText( itm->text(2) );
-    m_dialog->iface_netmask->setText( itm->text(3) );
-    m_dialog->iface_reg->setChecked( itm->text(4).isEmpty() );
-    m_dialog->iface_dyn->setChecked( itm->text(4).indexOf("Dyn")!=-1 );
-    m_dialog->iface_unnum->setChecked( itm->text(4).indexOf("Unn")!=-1 );
-    m_dialog->iface_bridgeport->setChecked( itm->text(4).indexOf("Bridge")!=-1 );
-    m_dialog->iface_physaddr->setText( itm->text(5) );
+    if (itm)
+    {
+        m_dialog->iface_name->setText( itm->text(0) );
+        m_dialog->iface_label->setText( itm->text(1) );
+        m_dialog->iface_addr->setText( itm->text(2) );
+        m_dialog->iface_netmask->setText( itm->text(3) );
+        m_dialog->iface_reg->setChecked( itm->text(4).isEmpty() );
+        m_dialog->iface_dyn->setChecked( itm->text(4).indexOf("Dyn")!=-1 );
+        m_dialog->iface_unnum->setChecked( itm->text(4).indexOf("Unn")!=-1 );
+        m_dialog->iface_bridgeport->setChecked( itm->text(4).indexOf("Bridge")!=-1 );
+        m_dialog->iface_physaddr->setText( itm->text(5) );
+    }
 }
 
 void newFirewallDialog::updateInterface()
@@ -879,17 +876,25 @@ void newFirewallDialog::finishClicked()
 
             int sl = itm2->text(3).toInt();
 
-            Interface *oi = Interface::cast(mw->createObject(
-                                                nfw,
-                                                Interface::TYPENAME,
-                                                name));
-            oi->setLabel( label.toLatin1().constData() );
+            Interface *oi = Interface::cast(mw->db()->create(Interface::TYPENAME));
+            assert(oi!=NULL);
+
+            nfw->add(oi);
+
+            oi->setName(name.toStdString());
+            oi->setLabel(label.toStdString());
 
             oi->setDyn(dyn);
             oi->setUnnumbered(unnum);
             oi->setBridgePort(bridgeport);
             oi->setSecurityLevel(sl);
 
+            mw->insertObjectInTree(nfw, oi);
+
+            if (fwbdebug)
+                qDebug("Adding interface %s: security_level=%d",
+                       oi->getName().c_str(), sl);
+
             if (!dyn && !unnum && !bridgeport &&
                 !addr.isEmpty() && addr!="0.0.0.0")
             {
@@ -898,9 +903,9 @@ void newFirewallDialog::finishClicked()
                     // ipv6 address
                     QString addrname = QString("%1:%2:ip6")
                         .arg(m_dialog->obj_name->text()).arg(name);
-                    IPv6 *oa = IPv6::cast(
-                        mw->createObject(oi, IPv6::TYPENAME, addrname)
-                    );
+                    IPv6 *oa = IPv6::cast(mw->db()->create(IPv6::TYPENAME));
+                    oi->add(oa);
+                    oa->setName(addrname.toStdString());
                     oa->setAddress(
                         InetAddr(AF_INET6, addr.toLatin1().constData()) );
                     bool ok = false ;
@@ -915,15 +920,16 @@ void newFirewallDialog::finishClicked()
                             InetAddr(AF_INET6, netmask.toLatin1().constData()));
                     }
 
+                    mw->insertObjectInTree(oi, oa);
+
                 } else
                 {
                     QString addrname = QString("%1:%2:ip").arg(
                         m_dialog->obj_name->text()).arg(name);
-                    IPv4 *oa = IPv4::cast(
-                        mw->createObject(oi, IPv4::TYPENAME,addrname)
-                    );
+                    IPv4 *oa = IPv4::cast(mw->db()->create(IPv4::TYPENAME));
+                    oi->add(oa);
+                    oa->setName(addrname.toStdString());
                     oa->setAddress( InetAddr(addr.toLatin1().constData()) );
-
                     bool ok = false ;
                     int inetmask = netmask.toInt(&ok);
                     if (ok)
@@ -935,6 +941,8 @@ void newFirewallDialog::finishClicked()
                         oa->setNetmask(
                             InetAddr(netmask.toLatin1().constData()) );
                     }
+
+                    mw->insertObjectInTree(oi, oa);
                 }
             }
 
