@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp 792 2009-03-25 04:43:16Z vadim $
+  $Id: platforms.cpp 929 2009-05-12 22:43:57Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -268,7 +268,8 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
                        opt->getInt("pf_max_src_conn")<=0       &&
                        opt->getInt("pf_max_src_conn_rate_num")<=0       &&
                        opt->getInt("pf_max_src_conn_rate_seconds")<=0 &&
-                       ! opt->getBool("pf_keep_state")
+                       ! opt->getBool("pf_keep_state") &&
+                       ! opt->getBool("pf_sloppy_tracker")
                 );
             }else
             {
@@ -277,7 +278,8 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
                        ! opt->getBool("pf_source_tracking")    &&
                        opt->getInt("pf_max_src_conn")<=0       &&
                        opt->getInt("pf_max_src_conn_rate_num")<=0       &&
-                       opt->getInt("pf_max_src_conn_rate_seconds")<=0
+                       opt->getInt("pf_max_src_conn_rate_seconds")<=0 &&
+                       ! opt->getBool("pf_sloppy_tracker")
                 );
             }
 	}
