@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: solarisAdvancedDialog.cpp,v 1.3 2006/03/16 05:38:14 vkurland Exp $
+  $Id: solarisAdvancedDialog.cpp 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,19 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "platforms.h"
 
 #include "solarisAdvancedDialog.h"
-#include "ObjectManipulator.h"
-
+#include "FWWindow.h"
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
 
@@ -38,17 +37,23 @@
 #include <qcombobox.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
-#include <qwidgetstack.h>
+#include <qstackedwidget.h>
 #include <qregexp.h>
 
 
 using namespace std;
 using namespace libfwbuilder;
 
+solarisAdvancedDialog::~solarisAdvancedDialog()
+{
+    delete m_dialog;
+}
 
 solarisAdvancedDialog::solarisAdvancedDialog(QWidget *parent,FWObject *o)
-    : solarisAdvancedDialog_q(parent)
+    : QDialog(parent)
 {
+    m_dialog = new Ui::solarisAdvancedDialog_q;
+    m_dialog->setupUi(this);
     obj=o;
 
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
@@ -68,31 +73,31 @@ solarisAdvancedDialog::solarisAdvancedDialog(QWidget *parent,FWObject *o)
     threeStateMapping.push_back(QObject::tr("Off"));
     threeStateMapping.push_back("0");
 
-    data.registerOption(  solaris_ip_forward,
+    data.registerOption(  m_dialog->solaris_ip_forward,
                           fwopt,
                           "solaris_ip_forward", threeStateMapping);
-    data.registerOption(  solaris_ip_forward_src_routed,
+    data.registerOption(  m_dialog->solaris_ip_forward_src_routed,
                           fwopt,
                           "solaris_ip_forward_src_routed", threeStateMapping);
-    data.registerOption(  solaris_ip_forward_directed_broadcasts,
+    data.registerOption(  m_dialog->solaris_ip_forward_directed_broadcasts,
                           fwopt,
                           "solaris_ip_forward_directed_broadcasts", threeStateMapping);
-    data.registerOption(  solaris_ip_respond_to_echo_broadcast,
+    data.registerOption(  m_dialog->solaris_ip_respond_to_echo_broadcast,
                           fwopt,
                           "solaris_ip_respond_to_echo_broadcast", threeStateMapping);
-    data.registerOption(  solaris_ip_forward_directed_broadcasts,
+    data.registerOption(  m_dialog->solaris_ip_forward_directed_broadcasts,
                           fwopt,
                           "solaris_ip_forward_directed_broadcasts", threeStateMapping);
-    data.registerOption(  solaris_ip_ignore_redirect,
+    data.registerOption(  m_dialog->solaris_ip_ignore_redirect,
                           fwopt,
                           "solaris_ip_ignore_redirect", threeStateMapping);
-    data.registerOption(  solaris_ip_forward_src_routed,
+    data.registerOption(  m_dialog->solaris_ip_forward_src_routed,
                           fwopt,
                           "solaris_ip_forward_src_routed", threeStateMapping);
-    data.registerOption(  solaris_path_ipf  ,
+    data.registerOption(  m_dialog->solaris_path_ipf  ,
                           fwopt,
                           "solaris_path_ipf");
-    data.registerOption(  solaris_path_ipnat,
+    data.registerOption(  m_dialog->solaris_path_ipnat,
                           fwopt,
                           "solaris_path_ipnat");
 
@@ -113,13 +118,13 @@ void solarisAdvancedDialog::accept()
 
     data.saveAll();
 
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
-    solarisAdvancedDialog_q::accept();
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    QDialog::accept();
 }
 
 void solarisAdvancedDialog::reject()
 {
-    solarisAdvancedDialog_q::reject();
+    QDialog::reject();
 }
 
 
