@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: iosacl.cpp 598 2008-10-10 15:29:55Z vadim $
+  $Id: iosacl.cpp 787 2009-03-19 14:42:35Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -47,6 +47,7 @@
 #include <cstring>
 
 #include "PolicyCompiler_iosacl.h"
+#include "RoutingCompiler_iosacl.h"
 #include "OSConfigurator_ios.h"
 
 #include "fwcompiler/Preprocessor.h"
@@ -117,6 +118,186 @@ void usage(const char *name)
     cout << "Usage: " << name << " [-tvV] [-f filename.xml] [-d destdir] [-o output.fw] firewall_object_name" << endl;
 }
 
+string safetyNetInstall(Firewall *fw)
+{
+    ostringstream output;
+    if ( fw->getOptionsObject()->getBool("iosacl_acl_substitution") )
+    {
+        /* Generate short temporary ACL and assign it to all
+         * interfaces. This ACL permits IPSEC (IP proto 50 and UDP port 500)
+         as well as ssh from given subnet to any.
+        */
+
+        string platform = fw->getStr("platform");
+        string version = fw->getStr("version");
+
+        string temp_acl = "tmp_acl";
+        string temp_acl_addr = fw->getOptionsObject()->getStr(
+            "iosacl_acl_temp_addr");
+
+        if (temp_acl_addr.empty())
+        {
+            cerr << "Missing address for management host or subnet for temporary ACL.\nPlease enter it in the tab 'Script options' in 'Firewall Settings' dialog"
+                 << endl;
+            exit(-1);
+        }
+
+        // if templ_acl_addr is ipv4 address, then we can not create this
+        // temporary ACL while compiling ipv6 policy. And vice versa.
+
+        bool create_temp_acl = false;
+        bool tmp_acl_ipv6 = false;
+        if (temp_acl_addr.find(":")!=string::npos)
+        {
+            //looks like ipv6
+            create_temp_acl = true;
+            tmp_acl_ipv6 = true;
+        } else
+        {
+            // not ipv6, assume ipv4
+            create_temp_acl = true;
+            tmp_acl_ipv6 = false;
+        }
+
+        if (create_temp_acl)
+        {
+            string::size_type slash_idx = temp_acl_addr.find('/');
+            string addr = temp_acl_addr;
+            string netmask = "255.255.255.255";
+            bool tmp_acl_v6 = false;
+
+            // check if addr is v6
+
+            try
+            {
+                InetAddr addrv6(AF_INET6, temp_acl_addr);
+                tmp_acl_v6 = true;
+            } catch(FWException &ex)
+            {
+                // Assume cnf->maddr is ipv4 
+                if (slash_idx!=string::npos)
+                {
+                    addr = temp_acl_addr.substr(0,slash_idx);
+                    netmask = temp_acl_addr.substr(slash_idx+1);
+                    try
+                    {
+                        if (netmask.find(".")!=string::npos)
+                        {
+                            InetAddr nm(netmask);
+                            nm.getLength(); // to avoid warning abt unused var
+                        } else
+                        {
+                            int nm_length;
+                            istringstream  str(netmask);
+                            str >> nm_length;
+                            InetAddr nm(nm_length);
+                            netmask = nm.toString();
+                        }
+                    } catch(FWException &ex)
+                    {
+                        cerr << "Invalid netmask for management subnet: '"+netmask+"'"
+                             << endl;
+                        exit(-1);
+                    }
+                }
+
+                try
+                {
+                    InetAddr a(addr);
+                    a.isAny();
+                } catch(FWException &ex)
+                {
+                    cerr << "Invalid address for management subnet: '"+addr+"'"
+                         << endl;
+                    exit(-1);
+                }
+            }
+
+            string xml_element = "clear_ip_acl";
+            if (tmp_acl_ipv6) xml_element = "clear_ipv6_acl";
+
+            string clearACLcmd = Resources::platform_res[platform]->getResourceStr(
+                string("/FWBuilderResources/Target/options/")+
+                "version_"+version+"/iosacl_commands/" + xml_element);
+
+            output << endl;
+
+            string addr_family_prefix = "ip";
+
+            string access_group_cmd =
+                PolicyCompiler_iosacl::getAccessGroupCommandForAddressFamily(tmp_acl_v6);
+
+            output << "! temporary access list for \"safety net install\""
+                   << endl;
+            output << endl;
+
+            if (tmp_acl_v6)
+            {
+                addr_family_prefix = "ipv6";
+                output << clearACLcmd << " " << temp_acl << endl;
+                output << "ipv6 access-list " << temp_acl << endl;
+                if (slash_idx!=string::npos)
+                    output << "  permit ipv6 " << addr << " any " << endl;
+                else
+                    output << "  permit ipv6 host " << addr << " any " << endl;
+                output << "  permit icmp any any " << endl;
+                output << "  deny ipv6 any any " << endl;
+                output << "exit" << endl;
+                output << endl;
+            } else
+            {
+                // cisco uses "wildcards" instead of netmasks
+
+                //long nm = InetAddr(netmask).to32BitInt();
+                //struct in_addr na;
+                //na.s_addr = ~nm;
+                InetAddr nnm( ~(InetAddr(netmask)) );
+                addr_family_prefix = "ip";
+                output << clearACLcmd << " " << temp_acl << endl;
+                output << "ip access-list extended " << temp_acl << endl;
+                output << "  permit ip "
+                       << addr << " " << nnm.toString() << " any " << endl;
+                output << "  deny ip any any " << endl;
+                output << "exit" << endl;
+                output << endl;
+            }
+
+            // find management interface
+            int nmi = 0;
+            list<FWObject*> ll = fw->getByType(Interface::TYPENAME);
+            for (FWObject::iterator i=ll.begin(); i!=ll.end(); i++)
+            {
+                Interface *intf = Interface::cast( *i );
+                if (intf->isManagement())
+                {
+                    nmi++;
+                    output << "interface " << intf->getName() << endl;
+                    output << "  no " << addr_family_prefix << " ";
+                    output << access_group_cmd;
+                    output << " in" << endl;
+
+                    output << "  no " << addr_family_prefix << " ";
+                    output << access_group_cmd;
+                    output << " out" << endl;
+
+                    output << " " << addr_family_prefix << " ";
+                    output << access_group_cmd;
+                    output << " " << temp_acl << " in" << endl;
+                    output << "exit" << endl;
+                }
+            }
+            if (nmi==0)
+            {
+                cerr << "One of the interfaces of the firewall must be marked as management interface."
+                     << endl;
+                exit(-1);
+            }
+
+            output << endl;
+        }
+    }
+    return output.str();
+}
 
 int main(int argc, char * const * argv)
 {   
@@ -223,7 +404,7 @@ int main(int argc, char * const * argv)
     try
     {
         new Resources(respath+FS_SEPARATOR+"resources.xml");
-
+ 
 /* create database */
         objdb = new FWObjectDatabase();
 
@@ -261,6 +442,17 @@ int main(int argc, char * const * argv)
         string fwvers = fw->getStr("version");
         if (fwvers == "") fw->setStr("version", "12.x");
 
+        string platform = fw->getStr("platform");
+        string clearACLCmd = Resources::platform_res[platform]->getResourceStr(
+            string("/FWBuilderResources/Target/options/") +
+            "version_" + fwvers + "/iosacl_commands/clear_ip_acl");
+        if (clearACLCmd.empty())
+        {
+            // incorrect version. This could have happened if user converted
+            // firewall platform. See bug #2662290
+            fw->setStr("version", "12.x");
+        }
+
         bool ios_acl_basic=options->getBool("ios_acl_basic");
         bool ios_acl_no_clear=options->getBool("ios_acl_no_clear");
         bool ios_acl_substitution=options->getBool("ios_acl_substitution");
@@ -351,9 +543,12 @@ int main(int argc, char * const * argv)
 
         int policy_rules_count  = 0;
 
-        vector<bool> ipv4_6_runs;
+        vector<int> ipv4_6_runs;
         string generated_script;
 
+        generated_script = safetyNetInstall(fw);
+
+
         // command line options -4 and -6 control address family for which
         // script will be generated. If "-4" is used, only ipv4 part will 
         // be generated. If "-6" is used, only ipv6 part will be generated.
@@ -362,20 +557,21 @@ int main(int argc, char * const * argv)
         if (options->getStr("ipv4_6_order").empty() ||
             options->getStr("ipv4_6_order") == "ipv4_first")
         {
-            if (ipv4_run) ipv4_6_runs.push_back(false);
-            if (ipv6_run) ipv4_6_runs.push_back(true);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
         }
 
         if (options->getStr("ipv4_6_order") == "ipv6_first")
         {
-            if (ipv6_run) ipv4_6_runs.push_back(true);
-            if (ipv4_run) ipv4_6_runs.push_back(false);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
         }
 
-        for (vector<bool>::iterator i=ipv4_6_runs.begin(); 
+        for (vector<int>::iterator i=ipv4_6_runs.begin(); 
              i!=ipv4_6_runs.end(); ++i)
         {
-            bool ipv6_policy = *i;
+            int policy_af = *i;
+            bool ipv6_policy = (policy_af == AF_INET6);
 
             // Count rules for each address family
             int policy_count = 0;
@@ -384,7 +580,7 @@ int main(int argc, char * const * argv)
                  p!=all_policies.end(); ++p)
             {
                 Policy *policy = Policy::cast(*p);
-                if (policy->isV6()==ipv6_policy) policy_count++;
+                if (policy->matchingAddressFamily(policy_af)) policy_count++;
             }
             if (policy_count)
             {
@@ -398,7 +594,7 @@ int main(int argc, char * const * argv)
             {
                 Policy *policy = Policy::cast(*p);
 
-                if (policy->isV6()!=ipv6_policy) continue;
+                if (!policy->matchingAddressFamily(policy_af)) continue;
 
                 PolicyCompiler_iosacl c(objdb, fwobjectname,
                                         ipv6_policy, oscnf);
@@ -439,6 +635,34 @@ int main(int argc, char * const * argv)
                 } else
                     cout << " Nothing to compile in Policy \n" << flush;
             }
+
+            if (!ipv6_policy)
+            {
+                // currently routing is supported only for ipv4
+                RoutingCompiler_iosacl r( objdb, fwobjectname, false, oscnf);
+
+                if (test_mode) r.setTestMode();
+                r.setDebugLevel( dl );
+                r.setDebugRule(  drp );
+                r.setVerbose( verbose );
+                
+                if ( r.prolog() > 0 )
+                {
+                    r.compile();
+                    r.epilog();
+
+                    if (r.haveErrorsAndWarnings())
+                    {
+                        generated_script +=
+                            "! Routing compiler errors and warnings:";
+                        generated_script += "\n";
+                        generated_script += r.getErrors("! ");
+                    }
+
+                    generated_script += r.getCompiledScript();
+                } else
+                    cout << " Nothing to compile in Routing \n" << flush;
+            }
         }
 
 #ifdef _WIN32
@@ -460,11 +684,8 @@ int main(int argc, char * const * argv)
 
         ofile << endl;
 
-        string vers = fw->getStr("version");
-        string platform = fw->getStr("platform");
-
         ofile << "!" << endl;
-        ofile << "!" << " Compiled for " << platform << " " << vers << endl;
+        ofile << "!" << " Compiled for " << platform << " " << fwvers << endl;
 
         ofile << "!" << endl;
         ofile << "!" << MANIFEST_MARKER << "* " << ofname << endl;
