@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipfw.cpp 585 2008-10-09 05:08:41Z vadim $
+  $Id: ipfw.cpp 692 2008-12-16 05:03:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -399,7 +399,7 @@ int main(int argc, char * const *argv)
 
 
         list<FWObject*> all_policies = fw->getByType(Policy::TYPENAME);
-        vector<bool> ipv4_6_runs;
+        vector<int> ipv4_6_runs;
         string generated_script;
         int policy_rules_count  = 0;
         int ipfw_rule_number = 0;
@@ -414,20 +414,21 @@ int main(int argc, char * const *argv)
         if (options->getStr("ipv4_6_order").empty() ||
             options->getStr("ipv4_6_order") == "ipv4_first")
         {
-            if (ipv4_run) ipv4_6_runs.push_back(false);
-            if (ipv6_run) ipv4_6_runs.push_back(true);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
         }
 
         if (options->getStr("ipv4_6_order") == "ipv6_first")
         {
-            if (ipv6_run) ipv4_6_runs.push_back(true);
-            if (ipv4_run) ipv4_6_runs.push_back(false);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
         }
 
-        for (vector<bool>::iterator i=ipv4_6_runs.begin(); 
+        for (vector<int>::iterator i=ipv4_6_runs.begin(); 
              i!=ipv4_6_runs.end(); ++i)
         {
-            bool ipv6_policy = *i;
+            int policy_af = *i;
+            bool ipv6_policy = (policy_af == AF_INET6);
 
             /*
               We need to create and run preprocessor for this address
@@ -443,7 +444,7 @@ int main(int argc, char * const *argv)
                  p!=all_policies.end(); ++p)
             {
                 Policy *policy = Policy::cast(*p);
-                if (policy->isV6()==ipv6_policy) policy_count++;
+                if (policy->matchingAddressFamily(policy_af)) policy_count++;
             }
 
             if (policy_count)
@@ -463,7 +464,7 @@ int main(int argc, char * const *argv)
                 Policy *policy = Policy::cast(*p);
                 string branch_name = policy->getName();
 
-                if (policy->isV6()!=ipv6_policy) continue;
+                if (!policy->matchingAddressFamily(policy_af)) continue;
 
                 PolicyCompiler_ipfw c(objdb, fwobjectname, ipv6_policy, oscnf);
                 c.setIPFWNumber(ipfw_rule_number);
