@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.h 617 2008-10-18 18:45:02Z vadim $
+  $Id: NATCompiler_ipt.h 752 2009-01-30 04:54:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -583,7 +583,8 @@ namespace fwcompiler {
 	
         void setHaveDynamicInterfaces(bool f) { have_dynamic_interfaces=f; }
         
-        std::string flushAndSetDefaultPolicy();
+        virtual std::string flushAndSetDefaultPolicy();
+        virtual std::string printAutomaticRules();
         std::string commit();
 
 	static std::string getNewTmpChainName(libfwbuilder::NATRule *rule);
