@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp 751 2009-01-25 06:35:06Z vadim $
+  $Id: PolicyCompiler_PrintRule.cpp 1042 2009-06-06 22:19:19Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -805,47 +805,49 @@ string PolicyCompiler_ipt::PrintRule::_printICMP(ICMPService *srv)
     return str.str();
 }
 
-string PolicyCompiler_ipt::PrintRule::_printIP(IPService *srv)
+string PolicyCompiler_ipt::PrintRule::_printIP(IPService *srv, PolicyRule *rule)
 {
     PolicyCompiler_ipt *ipt_comp=dynamic_cast<PolicyCompiler_ipt*>(compiler);
     std::ostringstream  str;
-    IPService *ip;
-    if ((ip=IPService::cast(srv))!=NULL)
+    if (srv->getBool("fragm") || srv->getBool("short_fragm"))
     {
-	if (srv->getBool("fragm") || srv->getBool("short_fragm"))
+        if (ipt_comp->ipv6) str << " -m frag --fragmore";
+        else str << " -f ";
+    }
+
+    string tos = srv->getTOSCode();
+    string dscp = srv->getDSCPCode();
+    if (!tos.empty())
+        str << " -m tos --tos " << tos;
+    else
+        if (!dscp.empty())
         {
-            if (ipt_comp->ipv6) str << " -m frag --fragmore";
-            else str << " -f ";
+            if (dscp.find("BE")==0 || 
+                dscp.find("EF")==0 || 
+                dscp.find("AF")==0 || 
+                dscp.find("CS")==0)
+                str << " -m dscp --dscp-class " << dscp;
+            else
+                str << " -m dscp --dscp " << dscp;
         }
-
-        string tos = ip->getTOSCode();
-        string dscp = ip->getDSCPCode();
-        if (!tos.empty())
-            str << " -m tos --tos " << tos;
-        else
-            if (!dscp.empty())
-            {
-                if (dscp.find("BE")==0 || 
-                    dscp.find("EF")==0 || 
-                    dscp.find("AF")==0 || 
-                    dscp.find("CS")==0)
-                    str << " -m dscp --dscp-class " << dscp;
-                else
-                    str << " -m dscp --dscp " << dscp;
-            }
         
-
+    if  (srv->getBool("lsrr") ||
+         srv->getBool("ssrr") ||
+         srv->getBool("rr") ||
+         srv->getBool("ts") )
+    {
         if (!ipt_comp->ipv6)
         {
-            if  (srv->getBool("lsrr") ||
-                 srv->getBool("ssrr") ||
-                 srv->getBool("rr") ||
-                 srv->getBool("ts") ) str << " -m ipv4options ";
-
+            str << " -m ipv4options ";
             if  (srv->getBool("lsrr")) str << " --lsrr";
             if  (srv->getBool("ssrr")) str << " --ssrr";
             if  (srv->getBool("rr"))   str << " --rr";
             if  (srv->getBool("ts"))   str << " --ts";
+        } else
+        {
+            compiler->abort(
+                string("IP options match is not supported for IPv6. Rule ") +
+                rule->getLabel());
         }
     }
     return str.str();
@@ -1018,7 +1020,7 @@ string PolicyCompiler_ipt::PrintRule::_printDstService(RuleElementSrv  *rel)
 	}
 	if (IPService::isA(srv)) 
         {
-	    string str=_printIP( IPService::cast(srv) );
+	    string str = _printIP(IPService::cast(srv), PolicyRule::cast(rel->getParent()));
 	    if (! str.empty() ) 
             {
                 ostr  << _printSingleObjectNegation(rel)
