@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h 752 2009-01-30 04:54:03Z vadim $
+  $Id: PolicyCompiler_ipt.h 1037 2009-06-05 16:58:28Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -833,6 +833,13 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(accounting);
 
+        /*
+         * Check if interface uses in the element "interface" has address
+         * that matches address family of the rule set. If interface does
+         * not have ipv6 address but rule set is ipv6, this interface will
+         * never see ipv6 packets and rule should be dropped.
+         */
+        DECLARE_POLICY_RULE_PROCESSOR(checkInterfaceAgainstAddressFamily);
         
         /**
          * if action is Continue and logging is off, skip this rule.
@@ -883,7 +890,8 @@ namespace fwcompiler {
             virtual std::string _printSrcPorts(libfwbuilder::Service *srv);
             virtual std::string _printDstPorts(libfwbuilder::Service *srv);
             virtual std::string _printICMP(libfwbuilder::ICMPService *srv);
-            virtual std::string _printIP(libfwbuilder::IPService *srv);
+            virtual std::string _printIP(libfwbuilder::IPService *srv,
+                                         libfwbuilder::PolicyRule *rule);
             virtual std::string _printTCPFlags(libfwbuilder::TCPService *srv);
             virtual std::string _printSrcAddr(libfwbuilder::RuleElement *rel,
                                               libfwbuilder::Address *o);
