@@ -102,35 +102,39 @@ struct CUSTOM_API IPTCfgParserTokenTypes {
 		NONE = 91,
 		MATCH_TCP_FLAGS = 92,
 		MATCH_TCP_OPTION = 93,
-		NUMBER = 94,
-		Whitespace = 95,
-		NEG_INT_CONST = 96,
-		HEXDIGIT = 97,
-		SECONDS = 98,
-		SET = 99,
-		RSOURCE = 100,
-		ULOG_QTHR = 101,
-		ULOG_NLG = 102,
-		ULOG_CPR = 103,
-		NUMBER_SIGN = 104,
-		PERCENT = 105,
-		AMPERSAND = 106,
-		APOSTROPHE = 107,
-		OPENING_PAREN = 108,
-		CLOSING_PAREN = 109,
-		PLUS = 110,
-		DOT = 111,
-		SEMICOLON = 112,
-		LESS_THAN = 113,
-		EQUALS = 114,
-		GREATER_THAN = 115,
-		QUESTION = 116,
-		COMMERCIAL_AT = 117,
-		CARET = 118,
-		UNDERLINE = 119,
-		OPENING_BRACE = 120,
-		CLOSING_BRACE = 121,
-		TILDE = 122,
+		Whitespace = 94,
+		IPV6 = 95,
+		MAC_ADDRESS = 96,
+		NEG_INT_CONST = 97,
+		HEXDIGIT = 98,
+		NUM_3DIGIT = 99,
+		NUM_HEX_4DIGIT = 100,
+		NUMBER = 101,
+		SECONDS = 102,
+		SET = 103,
+		RSOURCE = 104,
+		ULOG_QTHR = 105,
+		ULOG_NLG = 106,
+		ULOG_CPR = 107,
+		NUMBER_SIGN = 108,
+		PERCENT = 109,
+		AMPERSAND = 110,
+		APOSTROPHE = 111,
+		OPENING_PAREN = 112,
+		CLOSING_PAREN = 113,
+		PLUS = 114,
+		DOT = 115,
+		SEMICOLON = 116,
+		LESS_THAN = 117,
+		EQUALS = 118,
+		GREATER_THAN = 119,
+		QUESTION = 120,
+		COMMERCIAL_AT = 121,
+		CARET = 122,
+		UNDERLINE = 123,
+		OPENING_BRACE = 124,
+		CLOSING_BRACE = 125,
+		TILDE = 126,
 		NULL_TREE_LOOKAHEAD = 3
 	};
 #ifdef __cplusplus
