@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw_writers.cpp 545 2008-09-19 20:27:58Z vadim $
+  $Id: PolicyCompiler_ipfw_writers.cpp 751 2009-01-25 06:35:06Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -82,25 +82,20 @@ void PolicyCompiler_ipfw::PrintRule::_printProtocol(Service *srv)
 
     if ( CustomService::isA(srv) )
     {
-	string cscode=
-            CustomService::cast(srv)->getCodeForPlatform( compiler->myPlatformName() );
-/*
- * This is really a hack
- *
- * CustomService object does not imply any specific protocol so
- * generally we can't add protocol name if Custom Service object is
- * used. However, there is one particular case where we have to
- * specify protocol 'tcp' instead of 'all', that is when CustomService
- * object is used to add an option 'established' which is only valid
- * for tcp protocol.
- *
- * Perhaps better solution would be to add optional protocol
- * specification to the CustomService object
- */
-        if (cscode=="established")
-            compiler->output << "tcp ";
+        // CustomService returns protocol name starting with v3.0.4
+        // However CustomService can return protocol name "any", which
+        // we should just skip. Also, in ipfw option "established" is
+        // only defined for tcp, so we should set protocol to "tcp" if
+        // custom service inserts this option.
+        string pn = srv->getProtocolName();
+        if (pn != "any") compiler->output << pn << " ";
         else
-            compiler->output << "all ";
+        {
+            string cscode = CustomService::cast(srv)->getCodeForPlatform(
+                compiler->myPlatformName() );
+            if (cscode=="established") compiler->output << "tcp ";
+            // custom service does not define protocol - do not add any.
+        }
         return;
     }
 
@@ -436,8 +431,9 @@ void PolicyCompiler_ipfw::PrintRule::_printDstService(RuleElementSrv  *rel)
 
     compiler->output << " ";
 /*
- *  TCP services with flags were separated in rule processor separateTCPWithFlags.
- *  We can count on objects like that being a single object in the SRV.
+ *  TCP services with flags were separated in rule processor
+ *  separateTCPWithFlags.  We can count on objects like that being a
+ *  single object in the SRV.
  */
     if (TCPService::isA(s1)) 
     {
@@ -450,7 +446,7 @@ void PolicyCompiler_ipfw::PrintRule::_printDstService(RuleElementSrv  *rel)
 
 string PolicyCompiler_ipfw::PrintRule::_printDstService(Service *srv,bool neg)
 {
-    string         res;
+    string  res;
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
@@ -467,7 +463,8 @@ string PolicyCompiler_ipfw::PrintRule::_printDstService(Service *srv,bool neg)
 
     if (CustomService::isA(srv)) 
     {
-	res= CustomService::cast(srv)->getCodeForPlatform( compiler->myPlatformName() ) + " ";
+	res= CustomService::cast(srv)->getCodeForPlatform(
+            compiler->myPlatformName() ) + " ";
     }
 
     return res;
