@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp 709 2008-12-25 20:38:53Z vadim $
+  $Id: PolicyCompiler_pf.cpp 1047 2009-06-08 21:43:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -347,10 +347,23 @@ bool PolicyCompiler_pf::fillDirection::processNext()
  * as long as it misses interface - we need to determine direction
  * again anyway.
  */
-    if (rule->getDirectionAsString()=="" || rule->getInterfaceId()==-1 )
-    {
+    if (rule->getDirection() == PolicyRule::Undefined)   // || rule->getInterfaceId()==-1 )
         rule->setDirection( PolicyRule::Both );
 
+/*
+ * Correction for bug #2791950 "no way to generate "pass out" rule
+ *  with no interface". Do not reset direction just because interface
+ *  rule element is "any", otherwise we can not create rule with no
+ *  interface spec:
+ *
+ * pass out quick inet from any to any
+ *
+ * If we reset direction here, instead of this one rule we get two,
+ * one "pass out" and another "pass in". However it is still useful to
+ * change direction if fw is in source or destination.
+ */
+    if (rule->getDirection() == PolicyRule::Both)
+    {
         Address  *src = compiler->getFirstSrc(rule);
         Address  *dst = compiler->getFirstDst(rule);
         //int fwid = compiler->getFwId();
@@ -502,7 +515,8 @@ bool PolicyCompiler_pf::SplitDirection::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
-    if (rule->getDirection()==PolicyRule::Both) {
+    if (rule->getDirection()==PolicyRule::Both)
+    {
 	PolicyRule *r= compiler->dbcopy->createPolicyRule();
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
@@ -1074,6 +1088,11 @@ void PolicyCompiler_pf::compile()
         add( new separateTagged("split on TagService"));
         add( new separateTOS("split on IPService with TOS"));
 
+        if (ipv6)
+            add( new DropIPv4Rules("drop ipv4 rules"));
+        else
+            add( new DropIPv6Rules("drop ipv6 rules"));
+
 	add( new verifyCustomServices(
                  "verify custom services for this platform"));
 //	add( new ProcessScrubOption(    "process 'scrub' option"         ));
