@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp 790 2009-03-24 07:31:48Z vadim $
+  $Id: PolicyCompiler_pf_writers.cpp 1037 2009-06-05 16:58:28Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -580,7 +580,7 @@ void PolicyCompiler_pf::PrintRule::_printDstService(RuleElementSrv  *rel)
             const IPService *ip = IPService::constcast(srv);
             string tos = ip->getTOSCode();
             string dscp = ip->getDSCPCode();
-            if (!tos.empty()) compiler->output << " tos " << tos;
+            if (!tos.empty()) compiler->output << " tos " << tos << " ";
             if (!dscp.empty())
                 compiler->abort("PF does not support DSCP matching");
         }
@@ -689,7 +689,7 @@ void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool )
     }
 
     const InetAddr *addr = o->getAddressPtr();
-    InetAddr mask = *(o->getNetmaskPtr());
+    InetAddr mask;
 
     if (Interface::cast(o)!=NULL)
     {
@@ -701,6 +701,9 @@ void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool )
 	}
 
 	mask = InetAddr(InetAddr::getAllOnes());
+    } else
+    {
+        mask = *(o->getNetmaskPtr());
     }
 
     if (o->dimension()==1) 
@@ -942,13 +945,11 @@ bool PolicyCompiler_pf::PrintRule::processNext()
         // "keep state" can be used with any protocol, while "modulate state"
         // and "synproxy state" can only be used with tcp.
 
-	if (compiler->getCachedFwOpt()->getBool("pf_synproxy") &&
-            tcpsrv!=NULL)
+	if (compiler->getCachedFwOpt()->getBool("pf_synproxy") && tcpsrv!=NULL)
 	    compiler->output << "synproxy state ";
         else
         {
-            if (compiler->getCachedFwOpt()->getBool("pf_modulate_state") &&
-                tcpsrv!=NULL)
+            if (compiler->getCachedFwOpt()->getBool("pf_modulate_state") && tcpsrv!=NULL)
                 compiler->output << "modulate state ";
             else
             {
@@ -984,6 +985,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
         if (ruleopt->getInt("pf_max_src_conn")>0)          nopt++;
         if (ruleopt->getStr("pf_max_src_conn_overload_table")!="") nopt++;
         if (ruleopt->getInt("pf_max_src_conn_rate_num")>0) nopt++;
+        if (ruleopt->getBool("pf_sloppy_tracker"))         nopt++;
 
         bool not_the_first = false;
         if (nopt)
@@ -997,6 +999,13 @@ bool PolicyCompiler_pf::PrintRule::processNext()
                 not_the_first = true;
             }
 
+            if (ruleopt->getBool("pf_sloppy_tracker"))
+            {
+                if (not_the_first) compiler->output << ",";
+                compiler->output << " sloppy ";
+                not_the_first = true;
+            }
+
             if (ruleopt->getBool("pf_source_tracking"))
             {
                 if (not_the_first) compiler->output << ",";
