@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: TableFactory.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: TableFactory.cpp 709 2008-12-25 20:38:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -123,7 +123,7 @@ void TableFactory::createTablesForRE(RuleElement *re,Rule *rule)
         tblgrp = tables[tblID];
     } else
     {
-        tblgrp=ObjectGroup::cast(dbroot->create(ObjectGroup::TYPENAME));
+        tblgrp = dbroot->createObjectGroup();
 // TODO: can two rules yeild the same name for the group using this method?
         std::ostringstream tblname;
         if (!ruleSetName.empty()) tblname << ruleSetName << ":";
