@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pix_writers.cpp,v 1.1 2008/03/06 06:49:00 vkurland Exp $
+  $Id: PolicyCompiler_pix_writers.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -161,15 +161,16 @@ bool PolicyCompiler_pix::PrintObjectGroupsAndClearCommands::processNext()
             {
                 Address *a=Address::cast(obj);
                 assert(a!=NULL);
-                IPAddress addr=a->getAddress();
+                const InetAddr *addr = a->getAddressPtr();
                 pix_comp->output << " network-object ";
-                if (Network::cast(obj)!=NULL) {
-                    Netmask   mask=a->getNetmask();
-                    pix_comp->output << addr.toString() << " ";
-                    pix_comp->output << mask.toString() << " ";
+                if (Network::cast(obj)!=NULL)
+                {
+                    const InetAddr *mask = a->getNetmaskPtr();
+                    pix_comp->output << addr->toString() << " ";
+                    pix_comp->output << mask->toString() << " ";
                 } else {
                     pix_comp->output << " host ";
-                    pix_comp->output << addr.toString() << " ";
+                    pix_comp->output << addr->toString() << " ";
                 }
                 pix_comp->output << endl;
                 break;
@@ -202,8 +203,8 @@ bool PolicyCompiler_pix::PrintObjectGroupsAndClearCommands::processNext()
                 Service *s=Service::cast(obj);
                 assert(s!=NULL);
 
-                int rs=s->getInt("dst_range_start");
-                int re=s->getInt("dst_range_end");
+                int rs=TCPUDPService::cast(s)->getDstRangeStart();
+                int re=TCPUDPService::cast(s)->getDstRangeEnd();
 
                 if (rs<0) rs=0;
                 if (re<0) re=0;
@@ -303,8 +304,8 @@ string PolicyCompiler_pix::PrintRule::_printSrcService(libfwbuilder::Service *sr
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("src_range_start");
-	int re=srv->getInt("src_range_end");
+	int rs=TCPUDPService::cast(srv)->getSrcRangeStart();
+	int re=TCPUDPService::cast(srv)->getSrcRangeEnd();
 
         if (rs<0) rs=0;
         if (re<0) re=0;
@@ -327,8 +328,8 @@ string PolicyCompiler_pix::PrintRule::_printDstService(libfwbuilder::Service *sr
     ostringstream  str;
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) {
-	int rs=srv->getInt("dst_range_start");
-	int re=srv->getInt("dst_range_end");
+	int rs=TCPUDPService::cast(srv)->getDstRangeStart();
+	int re=TCPUDPService::cast(srv)->getDstRangeEnd();
 
         if (rs<0) rs=0;
         if (re<0) re=0;
@@ -350,11 +351,6 @@ string PolicyCompiler_pix::PrintRule::_printDstService(libfwbuilder::Service *sr
 
 string PolicyCompiler_pix::PrintRule::_printAddr(libfwbuilder::Address  *o)
 {
-    ostringstream  str;
-
-    IPAddress srcaddr=o->getAddress();
-    Netmask   srcmask=o->getNetmask();
-
     if (Interface::cast(o)!=NULL)
     {
 	Interface *interface_=Interface::cast(o);
@@ -362,28 +358,47 @@ string PolicyCompiler_pix::PrintRule::_printAddr(libfwbuilder::Address  *o)
         {
 	    return string("interface ") + interface_->getLabel() + " ";
 	}
-
-	srcmask=Netmask("255.255.255.255");
     }
 
-    if (IPv4::cast(o)!=NULL) 
-	srcmask=Netmask("255.255.255.255");
+    ostringstream  str;
 
-
-    if (srcaddr.toString()=="0.0.0.0" && srcmask.toString()=="0.0.0.0")
+    const InetAddr *srcaddr = o->getAddressPtr();
+    if (srcaddr)
     {
-	str << "any ";
-    } else {
-	if (srcmask.toString()=="255.255.255.255")
+        InetAddr srcmask = *(o->getNetmaskPtr());
+
+        if (Interface::cast(o)!=NULL)
+            srcmask = InetAddr(InetAddr::getAllOnes());
+
+        if (IPv4::cast(o)!=NULL) 
+            srcmask = InetAddr(InetAddr::getAllOnes());
+
+
+        if (srcaddr->isAny() && srcmask.isAny())
         {
-	    str << "host " << srcaddr.toString() << " ";
-	} else
-        {
-	    str << srcaddr.toString() << " ";
-	    str << srcmask.toString() << " ";
-	}
+            str << "any ";
+        } else {
+            if (srcmask.isHostMask())
+            {
+                str << "host " << srcaddr->toString() << " ";
+            } else
+            {
+                str << srcaddr->toString() << " ";
+                str << srcmask.toString() << " ";
+            }
+        }
+        return str.str();
     }
-    return str.str();
+    ostringstream errstr;
+    errstr << "Object "
+           << o->getName()
+           << " (id="
+           << o->getId()
+           << ") "
+           << " has no ip address and can not be used "
+           << "in the rule.";
+    compiler->abort(errstr.str());
+    return ""; // to make compiler happy
 }
 
 bool PolicyCompiler_pix::PrintRule::suppressDuplicateICMPCommands(const string &cmd)
@@ -461,7 +476,7 @@ string    PolicyCompiler_pix::PrintRule::_printSSHTelnetCommand(PolicyRule *rule
     Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
     assert(rule_iface);
     
-    port=srv->getInt("dst_range_start");
+    port=TCPUDPService::cast(srv)->getDstRangeStart();
 
     for (FWObject::iterator i=rel->begin(); i!=rel->end(); ++i)
     {
@@ -500,15 +515,15 @@ string PolicyCompiler_pix::PrintRule::_printSingleSSHTelnetCommand(int port,
     if (port==23) 
     {
         res += "telnet ";
-        res += a->getAddress().toString() + " " 
-            + a->getNetmask().toString() + " "
+        res += a->getAddressPtr()->toString() + " " 
+            + a->getNetmaskPtr()->toString() + " "
             + interfaceLabel     + "\n";
     }
     if (port==22) 
     {
         res += "ssh    ";
-        res += a->getAddress().toString() + " " 
-            + a->getNetmask().toString() + " "
+        res += a->getAddressPtr()->toString() + " " 
+            + a->getNetmaskPtr()->toString() + " "
             + interfaceLabel     + "\n";
     }
     return res;
